@@ -25,8 +25,9 @@ check_period <- function(object) {
   }
 
   values <- c(object@year, object@month, object@day, object@hour, object@minute)
-  values <- na.omit(values)
-  if (sum(values - trunc(values))) {
+  values <- values[is.finite(values)]
+  diff <- sum(values - trunc(values))
+  if (diff != 0) {
     msg <- "periods must have integer values"
     errors <- c(errors, msg)
   }
@@ -390,7 +391,7 @@ setMethod("$<-", signature(x = "Period"), function(x, name, value) {
 #' period("2days 2hours 2mins 2secs")
 #' period("2 days, 2 hours, 2 mins, 2 secs")
 #' # Missing numerals default to 1. Repeated units are added up.
-#' duration("day day")
+#' period("day day")
 #'
 #' ### ISO 8601 parsing
 #'
@@ -401,7 +402,7 @@ setMethod("$<-", signature(x = "Period"), function(x, name, value) {
 #'
 #' ### Comparison with characters (from v1.6.0)
 #'
-#' duration("day 2 sec") > "day 1sec"
+#' period("day 2 sec") > "day 1sec"
 #'
 #' ### Elementary Constructors
 #'
@@ -471,11 +472,12 @@ parse_period <- function(x) {
     stop("Interval or Durations objects cannot be used as input to 'period()' constructor. Plese use 'as.period()'.")
   }
 
-  if (length(units) %% length(num) != 0) {
-    stop("Arguments `num` and `units` must have same length")
+  stop_incompatible_sizes(num, units)
+  if (length(units) > length(num)) {
+    num <- rep_len(num, length(units))
   }
 
-  .period_from_units(structure(num, names = units))
+  .period_from_units(structure(num, names = rep_len(units, length(num))))
 }
 
 .period_from_units <- function(pieces) {
